@@ -40,13 +40,29 @@ def __match_location(part):
         val = int(m[1])
         return f'BO{val:02}'
 
-    pattern_bot = r'BOT(\d|$)'
-    m = match(pattern_bot, part)
+    pattern_bot1 = r'BOT ?(\d|$)'
+    m = match(pattern_bot1, part)
     if m:
         val = m[1]
         val = int(val) if val else 0
         return f'BOT{val}'
 
+    # Ortho BO3   Ortho SAS1
+    pattern_bot2 = r'Ortho ?(BO|SAS)(\d)'
+    m = match(pattern_bot2, part)
+    if m:
+        if m[1] == 'SAS':
+            val = f'SAS{m[2]}'
+        else:
+            val = m[2]
+        return f'BOT{val}'
+
+    # Mater BO1   Mater BO2
+    pattern_mater = r'Mater ?BO(\d)'
+    m = match(pattern_mater, part)
+    if m:
+        return f'MATER{m[1]}'
+
     if 'sspi' in part.lower():
         return 'SSPI'
 
@@ -61,4 +77,7 @@ def __match_location(part):
     if m:
         return f'R{m[1][-1]}'
 
+    if 'endoscopie' in part.lower():
+        return 'ENDOS'
+
     return None
